==> ejc-supbid-impl-3.0.1-20220124.080804-130-sources.jar: com/ejianc/business/supbid/purchase/bean/PurchaseSchemeDetailEntity.java <==
package com.ejianc.business.supbid.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备采购报价明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_purchase_scheme_detail")
public class PurchaseSchemeDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="source_id")
    private String sourceId; // 招标信息主键
    @TableField(value="scheme_id")
    private Long schemeId; // 方案主键
    @TableField(value="source_material_id")
    private String sourceMaterialId; // 材料ID
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="source_material_type_id")
    private String sourceMaterialTypeId; // 材料分类ID
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料分类名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="brand")
    private String brand; // 品牌
    @TableField(value="calculate_type")
    private Integer calculateType; // 计量方式(0-理计,1-过磅,2-点数)
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="rate")
    private BigDecimal rate; // 税率
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="supplier_brand")
    private String supplierBrand; // 供货品牌
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="price_tax")
    private BigDecimal priceTax; // 单价(含税)
    @TableField(value="money")
    private BigDecimal money; // 总额
    @TableField(value="money_tax")
    private BigDecimal moneyTax; // 总额(含税)
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="supplier_memo")
    private String supplierMemo; // 备注


    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }
    public String getSourceMaterialId() {
        return sourceMaterialId;
    }

    public void setSourceMaterialId(String sourceMaterialId) {
        this.sourceMaterialId = sourceMaterialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSourceMaterialTypeId() {
        return sourceMaterialTypeId;
    }

    public void setSourceMaterialTypeId(String sourceMaterialTypeId) {
        this.sourceMaterialTypeId = sourceMaterialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }
    public Integer getCalculateType() {
        return calculateType;
    }

    public void setCalculateType(Integer calculateType) {
        this.calculateType = calculateType;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getSupplierBrand() {
        return supplierBrand;
    }

    public void setSupplierBrand(String supplierBrand) {
        this.supplierBrand = supplierBrand;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getPriceTax() {
        return priceTax;
    }

    public void setPriceTax(BigDecimal priceTax) {
        this.priceTax = priceTax;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getSupplierMemo() {
        return supplierMemo;
    }

    public void setSupplierMemo(String supplierMemo) {
        this.supplierMemo = supplierMemo;
    }
    
}

==> ejc-supbid-impl-3.0.1-20230809.113353-220-sources.jar: com/ejianc/business/supbid/purchase/bean/PurchaseSchemeDetailEntity.java <==
package com.ejianc.business.supbid.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备采购报价明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_purchase_scheme_detail")
public class PurchaseSchemeDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="source_id")
    private String sourceId; // 招标信息主键
    @TableField(value="scheme_id")
    private Long schemeId; // 方案主键
    @TableField(value="source_material_id")
    private String sourceMaterialId; // 材料ID
    @TableField(value="material_name")
    private String materialName; // 材料名称
    @TableField(value="material_code")
    private String materialCode; // 材料编码
    @TableField(value="source_material_type_id")
    private String sourceMaterialTypeId; // 材料分类ID
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料分类名称
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="brand")
    private String brand; // 品牌
    @TableField(value="calculate_type")
    private Integer calculateType; // 计量方式(0-理计,1-过磅,2-点数)
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="rate")
    private BigDecimal rate; // 税率
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="supplier_brand")
    private String supplierBrand; // 供货品牌
    @TableField(value="price")
    private BigDecimal price; // 单价
    @TableField(value="price_tax")
    private BigDecimal priceTax; // 单价(含税)
    @TableField(value="money")
    private BigDecimal money; // 总额
    @TableField(value="money_tax")
    private BigDecimal moneyTax; // 总额(含税)
    @TableField(value="tax")
    private BigDecimal tax; // 税额
    @TableField(value="supplier_memo")
    private String supplierMemo; // 备注

    @TableField(value="detail_rate")
    private java.math.BigDecimal detailRate; // 税率

    public BigDecimal getDetailRate() {
        return detailRate;
    }

    public void setDetailRate(BigDecimal detailRate) {
        this.detailRate = detailRate;
    }


    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSchemeId() {
        return schemeId;
    }

    public void setSchemeId(Long schemeId) {
        this.schemeId = schemeId;
    }
    public String getSourceMaterialId() {
        return sourceMaterialId;
    }

    public void setSourceMaterialId(String sourceMaterialId) {
        this.sourceMaterialId = sourceMaterialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getSourceMaterialTypeId() {
        return sourceMaterialTypeId;
    }

    public void setSourceMaterialTypeId(String sourceMaterialTypeId) {
        this.sourceMaterialTypeId = sourceMaterialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getBrand() {
        return brand;
    }

    public void setBrand(String brand) {
        this.brand = brand;
    }
    public Integer getCalculateType() {
        return calculateType;
    }

    public void setCalculateType(Integer calculateType) {
        this.calculateType = calculateType;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getSupplierBrand() {
        return supplierBrand;
    }

    public void setSupplierBrand(String supplierBrand) {
        this.supplierBrand = supplierBrand;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    public BigDecimal getPriceTax() {
        return priceTax;
    }

    public void setPriceTax(BigDecimal priceTax) {
        this.priceTax = priceTax;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public String getSupplierMemo() {
        return supplierMemo;
    }

    public void setSupplierMemo(String supplierMemo) {
        this.supplierMemo = supplierMemo;
    }
    
}
